<?php
/**
 * Admin class.
 *
 * @package Bvi
 * @since   1.0.0
 */

namespace Bvi\Core;

if ( ! class_exists( 'Bvi' ) ) {

	/**
	 * Class Bvi
	 * @package Bvi\Core
	 */
	class Bvi extends Core {

		/**
		 * Bvi constructor.
		 */
		public function __construct() {
			$option = $this->getOption();

			add_action( 'plugins_loaded', function () {
				load_plugin_textdomain( 'bvi', false, BVI_LANG_PATH );
			}, 10, 0 );

			if ( ! empty( $option['bviActive'] ) && filter_var( $option['bviActive'], FILTER_VALIDATE_BOOLEAN ) ) {
				add_action( 'wp_enqueue_scripts', [ $this, 'frontendAssets' ], 999, 0 );
				add_shortcode( 'bvi-shortcode', [ $this, 'shortcode' ] );
				add_shortcode( 'bvi', [ $this, 'shortcode' ] );
			}
		}

		/**
		 * Add bvi shortcode.
		 *
		 * @param array $attributes
		 *
		 * @return string
		 */
		public function shortcode( array $attributes ): string {
			$shortcode_atts = shortcode_atts(
				[
					'text'       => __( 'Версия сайта для слабовидящих', 'bvi' ),
					'images-eye' => 'false'
				],
				$attributes
			);

			if ( $shortcode_atts['images-eye'] === 'true' ) {
				$imagesEye = '<i class="bvi-images bvi-images-eye" style="width: 42px !important; height: 42px !important; margin-right: .5rem;></i>';
			} else {
				$imagesEye = '';
			}

			return '<a href="#" class="bvi-open">' . $imagesEye . esc_html( $shortcode_atts['text'] ) . '</a>';
		}

		/**
		 * Frontend assets.
		 */
		public function frontendAssets() {
			$option = $this->getOption();

			wp_register_style( 'bvi-style', BVI_URL_CSS . 'bvi.min.css', true, BVI_VERSION );
			wp_enqueue_style( 'bvi-style' );

			wp_register_script( 'bvi-script', BVI_URL_JS . 'bvi.min.js', false, BVI_VERSION, true );

			wp_localize_script( 'bvi-script', 'wp_bvi', [
				'option' => [
					'theme'         => (string) $option['bviTheme'],
					'font'          => (string) $option['bviFont'],
					'fontSize'      => (int) $option['bviFontSize'],
					'letterSpacing' => (string) $option['bviLetterSpacing'],
					'lineHeight'    => (string) $option['bviLineHeight'],
					'images'        => ( $option['bviImages'] === 'grayscale' ) ? $option['bviImages'] : filter_var( $option['bviImages'], FILTER_VALIDATE_BOOLEAN ),
					'reload'        => filter_var( $option['bviReload'], FILTER_VALIDATE_BOOLEAN ),
					'speech'        => filter_var( $option['bviSpeech'], FILTER_VALIDATE_BOOLEAN ),
					'builtElements' => filter_var( $option['bviBuiltElements'], FILTER_VALIDATE_BOOLEAN ),
					'panelHide'     => filter_var( $option['bviPanelHide'], FILTER_VALIDATE_BOOLEAN ),
					'panelFixed'    => filter_var( $option['bviPanelFixed'], FILTER_VALIDATE_BOOLEAN ),
					'lang'          => (string) $option['bviLang'],
				]
			] );
			wp_add_inline_script( 'bvi-script', 'var Bvi = new isvek.Bvi(wp_bvi.option);' );
			wp_enqueue_script( 'bvi-script' );
		}
	}
}
?>
