<?php
/**
 * Widget class.
 *
 * @package Bvi
 * @since   1.0.0
 */

namespace Bvi\Core;

if ( ! class_exists( 'Widget' ) ) {

	/**
	 * Class Widget
	 * @package Bvi\Core
	 */
	class Widget extends \WP_Widget {

		/**
		 * Widget constructor.
		 */
		public function __construct() {
			parent::__construct( 'Bvi_Widget', 'Button visually impaired' );
		}

		/**
		 * Echoes the widget content.
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			echo $args['before_widget'];

			$title = apply_filters( 'widget_title', $instance['title'] );

			echo '<p><a href="#" class="bvi-open">' . $title . '</a></p>';

			echo $args['after_widget'];
		}

		/**
		 * Updates a particular instance of a widget.
		 *
		 * @param array $new_instance
		 * @param array $old_instance
		 *
		 * @return array|void
		 */
		public function update( $new_instance, $old_instance ) {
			$instance = [];
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
			return $instance;
		}

		/**
		 * Outputs the settings update form.
		 *
		 * @param array $instance
		 *
		 * @return string|void
		 */
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';

			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">Название ссылки:</label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>
			<?php
		}
	}
}
